@@ -78,12 +78,14 @@ if(is.null(diss))
     } 
 }
 
-if((!is.null(diss))&&((distanceM==1)||(distanceM==2)|| (distanceM==3)|| (distanceM==4)|| (distanceM==5)|| (distanceM==6)))
-    stop("dissimilarity matrix and distance are both not null")
-
-if((!is.null(diss))&&(distanceM==7))
-  md <- diss 
-		  
+if(!is.null(diss))
+{
+  if((distanceM==1)||(distanceM==2)|| (distanceM==3)|| (distanceM==4)|| (distanceM==5)|| (distanceM==6))
+stop("dissimilarity matrix and distance are both not null")
+  else
+    md <- diss
+}
+   
 
   
     #&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&#
@@ -1099,25 +1101,29 @@ Indice.S <- function (d, cl)
     #                                                                      #
     ######################################################################## 
     
-    
 Indice.Gap <- function (x, clall, reference.distribution = "unif", B = 10, 
     method = "ward.D2", d = NULL, centrotypes = "centroids") 
 {
-    GAP <- function(X, cl, referenceDistribution, B, method, 
-        d, centrotypes) {
-        simgap <- function(Xvec) {
+    GAP <- function(X, cl, referenceDistribution, B, method, d, centrotypes) 
+      {
+        set.seed(1)
+        simgap <- function(Xvec) 
+          {
             ma <- max(Xvec)
             mi <- min(Xvec)
             set.seed(1)
             Xout <- runif(length(Xvec), min = mi, max = ma)
             return(Xout)
-        }
-        pcsim <- function(X, d, centrotypes) {
-            if (centrotypes == "centroids") {
+          }
+          pcsim <- function(X, d, centrotypes) 
+          {
+            if (centrotypes == "centroids") 
+            {
                 Xmm <- apply(X, 2, mean)
             }
             
-            for (k in (1:dim(X)[2])) {
+            for (k in (1:dim(X)[2])) 
+            {
                 X[, k] <- X[, k] - Xmm[k]
             }
             ss <- svd(X)
@@ -1129,7 +1135,8 @@ Indice.Gap <- function (x, clall, reference.distribution = "unif", B = 10,
             }
             return(Xt)
         }
-        if (is.null(dim(x))) {
+        if (is.null(dim(x))) 
+        {
             dim(x) <- c(length(x), 1)
         }
         ClassNr <- max(cl)
@@ -1167,12 +1174,13 @@ Indice.Gap <- function (x, clall, reference.distribution = "unif", B = 10,
                       ClassNr)
                   }
                 }
-                if (ClassNr == 1) {
+                if (ClassNr == 1) 
+                {
                   Wk0 <- sum(diag(var(X)))
                   WkB[1, bb] <- sum(diag(var(Xnew)))
                 }
-            }
-            if (bb > 1) {
+             }
+             if (bb > 1) {
                 if (ClassNr == length(cl)) 
                   pp2 <- 1:ClassNr
                 else if (method == "k-means")
@@ -1224,6 +1232,7 @@ Indice.Gap <- function (x, clall, reference.distribution = "unif", B = 10,
     diffu <- gap - (gap2$Sgap - gap2$Sdgap)
     resul <- list(gap = gap, diffu = diffu)
     resul
+
 }
     
     
